@@ -1,4 +1,5 @@
 import musicazoo.queue
+import musicazoo.settings as settings
 import musicazoo.lib.service as service
 from musicazoo.queue.module import Module
 import os
@@ -16,10 +17,19 @@ class Text(Module):
     TYPE_STRING='text'
     process = ['python','-m','musicazoo.queue.modules.text']
 
-modules = [Youtube, Problem, Text]
-backgrounds = [Youtube, Problem, Text]
+class TextBG(Module):
+    TYPE_STRING='text_bg'
+    process = ['python','-m','musicazoo.queue.modules.text_bg']
 
-q=musicazoo.queue.Queue(modules, backgrounds)
+class Image(Module):
+    TYPE_STRING='image'
+    process = ['python','-m','musicazoo.queue.modules.image']
+
+modules = [Youtube, Text]
+backgrounds = [TextBG, Image]
+
+#q=musicazoo.queue.Queue(modules, backgrounds, 'logfile.json')
+q=musicazoo.queue.Queue(modules, backgrounds, settings.log_database)
 
 def shutdown_handler(signum,frame):
     print
